## pynsq

[![Build Status](https://github.com/nsqio/pynsq/workflows/tests/badge.svg)](https://github.com/nsqio/pynsq/actions) [![GitHub release](https://img.shields.io/github/release/nsqio/pynsq.svg)](https://github.com/nsqio/pynsq/releases/latest) [![PyPI](https://img.shields.io/pypi/v/pynsq.svg)](https://pypi.org/project/pynsq)

The official Python client library for [NSQ][nsq].

### Installation

    $ pip install pynsq

### Docs

For HTML documentation, visit [https://pynsq.readthedocs.org/](https://pynsq.readthedocs.org/)

### Tests

`nsqd` and `nsqlookupd` are required to run tests, see [installing](https://nsq.io/deployment/installing.html).

     python setup.py test

[nsq]: https://github.com/nsqio/nsq